@@ -71,17 +71,13 @@ lav_options_default <- function(mimic = "lavaan") {
                 auto.delta         = FALSE,
                 auto.efa           = FALSE,
 
-                # seat belts
-                safe.ov.var.ub     = FALSE,
-                save.ov.var.lb     = FALSE,
-
                 # rotation
                 rotation           = "geomin",
                 rotation.se        = "bordered", # "bordered" or "delta"
                 rotation.args      = list(orthogonal     = FALSE,
                                           row.weights    = "default",
                                           std.ov         = TRUE,
-                                          geomin.epsilon = 0.01,
+                                          geomin.epsilon = 0.001, # was 0.01 < 0.6-10
                                           orthomax.gamma = 1,
                                           cf.gamma       = 0,
                                           oblimin.gamma  = 0,
@@ -173,6 +169,7 @@ lav_options_default <- function(mimic = "lavaan") {
                 em.h1.tol              = 1e-05, # was 1e-06 < 0.6-9
                 em.h1.warn             = TRUE,
                 optim.gn.iter.max      = 200L,
+                optim.gn.stephalf.max  = 10L,
                 optim.gn.tol.x         = 1e-05,
 
                 # numerical integration
@@ -327,13 +324,14 @@ lav_options_set <- function(opt = NULL) {
     # representation
     if(opt$representation == "default") {
         opt$representation <- "LISREL"
-    } else if(opt$representation == "lisrel") {
+    } else if(opt$representation %in% c("lisrel", "LISREL")) {
         opt$representation <- "LISREL"
-    } else if(opt$representation == "eqs" ||
-              opt$representation == "bentler-weeks") {
-        opt$representation <- "EQS"
+    #} else if(opt$representation %in% c("eqs", "EQS", "bentler-weeks")) {
+    #    opt$representation <- "EQS"
+    } else if(opt$representation %in% c("ram", "RAM")) {
+        opt$representation <- "RAM"
     } else {
-        stop("lavaan ERROR: representation must be \"LISREL\" or \"EQS\" \n")
+        stop("lavaan ERROR: representation must be \"LISREL\" or \"RAM\" \n")
     }
 
     # clustered
@@ -860,7 +858,13 @@ lav_options_set <- function(opt = NULL) {
         }
         #opt$missing <- "listwise"
     } else if(opt$estimator == "dls") {
-        opt$sample.cov.rescale <- TRUE # should we make this an option??
+        if(is.logical(opt$sample.cov.rescale)) {
+            # nothing to do
+        } else if(opt$sample.cov.rescale == "default") {
+            opt$sample.cov.rescale <- TRUE
+        } else {
+            stop("lavaan ERROR: sample.cov.rescale value must be logical.")
+        }
         opt$estimator <- "DLS"
         if(opt$se == "default") {
             opt$se <- "robust.sem"
@@ -892,7 +896,7 @@ lav_options_set <- function(opt = NULL) {
 
         # check estimator.args
         if(is.null(opt$estimator.args)) {
-            opt$estimator.args <- list(dls.a = 1.0, dls.GammaNT = "sample",
+            opt$estimator.args <- list(dls.a = 1.0, dls.GammaNT = "model",
                                        dls.FtimesNmin1 = FALSE)
         } else {
             if(is.null(opt$estimator.args$dls.a)) {
@@ -905,7 +909,7 @@ lav_options_set <- function(opt = NULL) {
                 }
             }
             if(is.null(opt$estimator.args$dls.GammaNT)) {
-                opt$estimator.args$dls.GammaNT <- "sample"
+                opt$estimator.args$dls.GammaNT <- "model"
             } else {
                 stopifnot(is.character(opt$estimator.args$dls.GammaNT))
                 opt$estimator.args$dls.GammaNT <-
@@ -920,23 +924,23 @@ lav_options_set <- function(opt = NULL) {
                 stopifnot(is.logical(opt$estimator.args$dls.FtimesNminus1))
             }
         }
-        # is 'sample' version, we allow both nlminb and gn
-        # if 'model' version, we only allow for gn
         if(opt$estimator.args$dls.GammaNT == "sample") {
             if(opt$optim.method %in% c("nlminb", "gn")) {
                 # nothing to do
             } else if(opt$optim.method == "default") {
                 opt$optim.method <- "gn"
             } else {
-                stop("lavaan ERROR: optim.method must be either nlminb or gn if estimator is sample based DLS.")
+                stop("lavaan ERROR: optim.method must be either nlminb or gn if estimator is DLS.")
             }
         } else {
             if(opt$optim.method %in% c("gn")) {
                 # nothing to do
             } else if(opt$optim.method == "default") {
                 opt$optim.method <- "gn"
+            } else if(opt$optim.method == "nlminb") {
+                opt$optim.gradient = "numerical"
             } else {
-                stop("lavaan ERROR: optim.method must be gn if estimator is model based DLS.")
+                stop("lavaan ERROR: optim.method must be either nlminb or gn if estimator is DLS.")
             }
         }
     } else if(opt$estimator == "dwls") {
@@ -1599,17 +1603,17 @@ lav_options_set <- function(opt = NULL) {
               opt$bounds == "wide") {
         opt$optim.bounds <- list(lower = c("ov.var", "lv.var", "loadings"),
                                  upper = c("ov.var", "lv.var", "loadings"),
-                                 lower.factor = c(1.2, 1.0, 1.1),
-                                 upper.factor = c(1.2, 1.3, 1.1),
+                                 lower.factor = c(1.05, 1.0, 1.1),
+                                 upper.factor = c(1.20, 1.3, 1.1),
                                  min.reliability.marker = 0.1,
-                                 min.var.lv.endo = 0.0)
+                                 min.var.lv.endo = 0.005)
     } else if(opt$bounds == "standard") {
         opt$optim.bounds <- list(lower = c("ov.var", "lv.var", "loadings"),
                                  upper = c("ov.var", "lv.var", "loadings"),
                                  lower.factor = c(1.0, 1.0, 1.0),
                                  upper.factor = c(1.0, 1.0, 1.0),
                                  min.reliability.marker = 0.1,
-                                 min.var.lv.endo = 0.0)
+                                 min.var.lv.endo = 0.005)
     } else if(opt$bounds == "pos.var") {
         opt$optim.bounds <- list(lower = c("ov.var", "lv.var"),
                                  lower.factor = c(1, 1),
@@ -1644,6 +1648,10 @@ lav_options_set <- function(opt = NULL) {
     } else if(opt$rotation %in% c("cf-quartimax", "cf-varimax", "cf-equamax",
                             "cf-parsimax", "cf-facparsim")) {
         # nothing to do here; we need M/P to set cf.gamma
+    } else if(opt$rotation %in% c("bi-quartimin", "biquartimin")) {
+        opt$rotation <- "biquartimin"
+    } else if(opt$rotation %in% c("bi-geomin", "bigeomin")) {
+        opt$rotation <- "bigeomin"
     } else {
         txt <- c("Rotation method ", dQuote(opt$rotation), " not supported. ",
         "Supported rotation methods are: varimax, quartimax, orthomax, cf, ",
